.. PartSegCore-compiled-backend documentation master file, created by
   sphinx-quickstart on Sat Jan 20 15:05:13 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root ``toctree`` directive.

Welcome to PartSegCore-compiled-backend's documentation!
========================================================

The PartSegCore-compiled-backend was created as package for PartSeg project.
It contains parts of code that needs to be compiled. It was created to simplify
maintenance of PartSeg project. But maybe you could find here useful functions.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   calc_bounds
   fast_unique
   napari_mapping
   sprawl_utils



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Cite as
=======

Bokota, G., Sroka, J., Basu, S. et al. PartSeg: a tool for quantitative feature extraction from 3D microscopy images for dummies. BMC Bioinformatics 22, 72 (2021). https://doi.org/10.1186/s12859-021-03984-1
